@@ -7,6 +7,14 @@ use lib 'lib';
 
 use Text::Editor::Easy;
 
+# Windows
+#my $path = 'E:\\site\\audio\\';
+#my $command = 'E:\\cpan\\oggdec.exe -p';
+
+# Linux
+my $path = '/media/hdc2/site/audio/';
+my $command = 'ogg123';
+
 Text::Editor::Easy->new( {
         'focus'    => 'yes',
 		'sub' => 'main',
@@ -15,7 +23,7 @@ Text::Editor::Easy->new( {
 sub main {
     my ( $editor ) = @_;
 
-        Text::Editor::Easy->create_new_server(
+    $editor->create_new_server(
         {
              'methods' => [
                 'play',
@@ -23,8 +31,29 @@ sub main {
             'object' => [],
         }
     );
+    $editor->create_new_server(
+        {
+             'methods' => [
+                'play2',
+            ],
+            'object' => [],
+        }
+    );
+    $editor->create_new_server(
+        {
+             'methods' => [
+                'play3',
+            ],
+            'object' => [],
+        }
+    );
+
+
+	my $async = $editor->async;
 	# Windows
-        Text::Editor::Easy::Async->play("E:\\site\\audio\\gladio.ogg");
+    $async->play('gladio.ogg');
+	$async->play2('Koln_part_2c.ogg');
+	$async->play3('room_27.ogg');
 	
 	# Linux
 	#Text::Editor::Easy::Async->play("/media/hdc2/site/audio/gladio.ogg");
@@ -36,12 +65,17 @@ sub main {
 	$editor->insert("Fin\n");
 }
 
+
 sub play {
 		my ( $self, $song ) = @_;
-		
-		# Windows command
-		`E:\\cpan\\oggdec.exe -p $song`;
-		
-		# Linux command
-		#`ogg123 -q $song`;
+
+		`$command $path$song`;
+}
+
+sub play2 {
+		play( @_ );
+}
+
+sub play3 {
+		play( @_ );
 }
