@@ -12,11 +12,11 @@ The process of regular save is launched only if the Editor.pl program finds a ".
 
 =head1 VERSION
 
-Version 0.46
+Version 0.47
 
 =cut
 
-our $VERSION = '0.46';
+our $VERSION = '0.47';
 
 use Text::Editor::Easy;
 use Text::Editor::Easy::Comm;
@@ -65,7 +65,8 @@ sub save_arbo {
         # Mthode pas trs propre pour appeler une mthode d'un objet pas cr dont on connait la rfrence... vite le bless et l'AUTOLOAD
         # Thread ddi => sauvegarde synchrone (pas de gestion de l'attente de fin d'excution)
         Text::Editor::Easy::Comm::ask_named_thread(
-            $ref,
+            #$ref,
+            Text::Editor::Easy->get_from_id( $ref ),
             'Text::Editor::Easy::File_manager::save_internal',
             'File_manager'
         );
